@@ -102,16 +102,18 @@ class _Regressor(object):
                           scoring='score',
                           cv_folds=5,
                           n_jobs=1,
+                          select=True,
                           allowed_grad=0.1,
                           select_perc=90):
         """
         Method to search optimal parameters for the regressor
-        :param param_dict:
-        :param scoring:
-        :param cv_folds:
-        :param n_jobs:
-        :param allowed_grad:
-        :param select_perc:
+        :param param_dict: Dictionary of parameter grid to search for best score
+        :param scoring: Score metric callable method from the regressor
+        :param cv_folds: number of folds to divide the samples in
+        :param n_jobs: number of parallel processes to run the grid search
+        :param select: if the best set of parameters should be selected
+        :param allowed_grad: max allowable percent difference between min and max score
+        :param select_perc: percentile to choose for best model selection
         """
         model = GridSearchCV(self.regressor,
                              param_dict,
@@ -121,21 +123,22 @@ class _Regressor(object):
 
         results = model.cv_results_
 
-        params = results['params']
-        mean_scores = results['mean_test_score']
-        std_scores = results['std_test_score']
-        ranks = results['rank_test_scores']
+        if select:
+            params = results['params']
+            mean_scores = results['mean_test_score']
+            std_scores = results['std_test_score']
+            ranks = results['rank_test_scores']
 
-        grad_cond = (std_scores.max() - std_scores.min())/std_scores.max() <= allowed_grad
-
-        if not grad_cond:
-            param = params[np.where(mean_scores == np.percentile(mean_scores,
-                                                                 select_perc,
-                                                                 interpolation='nearest'))]
+            grad_cond = (std_scores.max() - std_scores.min()) / std_scores.max() <= allowed_grad
+            if not grad_cond:
+                param = params[np.where(mean_scores == np.percentile(mean_scores,
+                                                                     select_perc,
+                                                                     interpolation='nearest'))]
+            else:
+                param = params[np.where(ranks == 1)]
+            self.cv_param = param
         else:
-            param = params[np.where(ranks == 1)]
-
-        self.cv_param = param
+            return results
 
     @staticmethod
     def get_defaults(**kwargs):
